#!/bin/bash
# Author : Guth (guth@ploposor.com)
# URL : http://oss.oetiker.ch/rrdtool/pub/rrdtool-1.3.4.tar.gz

# program name/version
FilenameFromUrl="$(grep 'U[R]L' $0 | rev | cut -d '/' -f1 | rev)"
softname="$(echo $FilenameFromUrl | cut -d '-' -f1)"
softversion="$(echo $FilenameFromUrl | cut -d '-' -f2 | cut -d '.' -f -3)"
#softversion='1.2.26'
#softname='rrdtool'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='54.1'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"
srcpkg="$buildir/$FilenameFromUrl"

if ! [ -f "$FilenameFromUrl" ]; then
    echo "Downloading the program tarball...$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)"
    wget "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" ||exit 0
fi


# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
rrdtool: An opensource data logging and graphing system for time series data
rrdtool:
rrdtool: RRDtool is the OpenSource industry standard, high performance data
rrdtool: logging and graphing system for time series data. Use it to write
rrdtool: your custom monitoring shell scripts or create whole applications
rrdtool: using its Perl, Python, Ruby, TCL or PHP bindings
rrdtool: 
rrdtool: 
rrdtool: 
rrdtool: 
rrdtool: 
EOF

# extract sources
echo "extracting ..."
srcdir="$softname-$softversion"
cd $buildir
rm -rf $srcdir
tar zxf $srcdir.tar.gz ||exit 0
#tar zxf $softname.tar.gz || exit
cd $srcdir || exit 0

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

# configure package for compilation

echo "configuring ..."

mkdir -p $dest/usr/doc/$softname-$softversion

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
   --prefix=/usr \
   --sysconfdir=/etc \
   --localstatedir=/var \
   --mandir=/usr/man \
   --enable-perl-site-install \
   --enable-ruby-site-install \
   --enable-tcl-site  || exit



#for file in $(find ./doc -name Makefile); do
#    echo "Patching ${file} docdir value"
#    sed "s/\$(datadir)\/doc\/rrdtools/\/usr\/doc\/$softname-$softversion/g" ${file} > ${file}_tmp
#    mv ${file}_tmp ${file}
#done

# compile package
make $ntasks || exit

# install package to the target directory
make install DESTDIR=$dest || exit

# copy the doc files

cp -a \
 CHANGES CONTRIBUTORS COPYING COPYRIGHT NEWS README THREADS TODO \
 WIN32-BUILD-TIPS.txt \
 $dest/usr/doc/$softname-$softversion

# strip executables
echo "stripping ..."
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# gzip man pages and info files
echo "gzipping ..."
gzip -9 $dest/usr/man/*/*

# put the ZenWalk build and other needed files in the right directory
echo "setting perms ..."
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
chown -R root.root $dest/usr/src/$softname-$softversion

# change files ownerships for $dest/usr/sbin
# NO $dest/usr/bin at all
chown -R root.root $dest/usr/bin
chown -R root.root $dest/usr/sbin



#------------------( Create The *.dep File )
echo "creating .dep ..."
cd $dest
#requiredbuilder -z $dest > $buildir/$package.dep || exit
#old one
#echo -n "freetype,libart_lgpl,libpng,perl,python,zlib" > $buildir/$package.dep
#new one
#echo -n "directfb,expat,fontconfig,freetype,glib2,glibc,gtk+2,libart_lgpl,libpng,libxml2,pango,perl,python,ruby,xcb,xorg-libs,zlib"> $buildir/$package.dep
#new one stripped, ... not sure
echo -n "directfb,expat,fontconfig,freetype,glib2,glibc,gtk+2,libart_lgpl,libpng,libxml2,pango,xcb,xorg-libs,zlib"> $buildir/$package.dep


cd $dest
/sbin/makepkg -l y -c n $package.tgz || exit
mv $package.tgz $buildir

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir
md5sum $package.tgz > $package.md5 || exit

echo "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" > $package.src
echo "http://zen-repo.meticul.eu/zen_stuffs/guth/packages/rrdtool/build-rrdtool.sh" >> $package.src

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi
